<?php

/**
 * Build the administrative menu shown to admins
 *
 * @return
 *  A string of HTML representing the admin menu
 */
function om_admin_menu() {
  $output = '<ul id="admin-nav">';
  if (module_exist('devel')) {
    $output .= '<li class="expanded"><a href="#">devel</a><ul class="menu">';
    $output .= '<li class="leaf"><a href="'. url('admin/settings/devel') .'">module settings</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/cache/clear') .'">empty cache</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/phpinfo') .'">phpinfo()</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/menu/reset') .'">reset menus</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/reinstall') .'">reinstall modules</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/variable') .'">variable viewer</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/execute') .'">execute php code</a></li>';
    $output .= '<li class="leaf"><a href="'. url('devel/node_access/summary') .'">node access summary</a></li>';
    $output .= '</ul></li>';
  }
  $output .= menu_tree(1);
  $output .= '</ul>';
  
  return $output;
}


/**
 * Theme lists of links semantically
 *
 * @param $level menu level to display links for, 1 is top is level
 * @param $parent_id name of id to apply to UL
 * @param $pid menu id to lookup, by default it looks up whatever menu_primary_menu setting is
 * @return HTML markup for navigation list
 */
function om_navigation($level, $parent_id, $pid = 0) {
  $menu_primary_links = menu_primary_links($level, $pid);
  $link_count = count($menu_primary_links);
  $i = 0;
  $ouput = '';
  
  if ($link_count > 0) {
    $output .= '<ul id="'. $parent_id .'">';
    
    foreach ($menu_primary_links AS $key => $link) {
      $class = '';

      if ($i == 0) {
        $class = 'first';
      }
      else if ($i == $link_count - 1) {
        $class = 'last';
      }
      
      // if this is an active link on <a> add 'active' to <li> as well
      if (strstr($key, 'active')) {
        $class .= ($class != '' ? ' ' : '') . 'active';
      }

      $output .= '<li '. ($class != '' ? 'class="'. $class .'"' : '') .'>'. $link .'</li>';

      $i++;
    }
    
    $output .= '</ul>';
  }
  
  return $output;
}


/**
 * Intercept template variables
 *
 * @param $hook
 *   The name of the theme function being executed
 * @param $vars
 *   A sequential array of variables passed to the theme function.
 */
function _phptemplate_variables($hook, $vars = array()) {
  static $comment_number = 1;
  
  switch ($hook) {
    case 'page':
      //if this is an admin page
      if ((arg(0) == 'admin') || 
          (arg(0) == 'node' && arg(1) == 'add') ||
          (arg(0) == 'node' && arg(2) == 'edit')) {
        $vars['is_admin'] = TRUE;
      }
      
      global $user;
      if ($user->uid == 1) {
        $vars['admin'] = TRUE;
      }
      
      if (arg(0) == 'node' && arg(1) == '87') {
        $vars['m3_home'] = TRUE;
      }
      break;
    case 'comment':
      $vars['comment_number'] = $comment_number++;
      $vars['zebra'] = ($comment_number % 2 == 0) ? 'even' : 'odd';
      $vars['admin_comment'] = $vars['comment']->uid == 1 ? TRUE : FALSE;
      break;
  }
  
  return $vars;
}